@@ -1,3 +1,4 @@
+
 require 'rails/generators/rails/generator/generator_generator'
 
 module Rails
@@ -5,6 +6,12 @@ module Rails
     class PluginGenerator < NamedBase
       class_option :tasks, :desc => "When supplied creates tasks base files."
 
+      def show_deprecation
+        return unless behavior == :invoke
+        message = "Plugin generator is deprecated, please use 'rails plugin new' command to generate plugin structure."
+        ActiveSupport::Deprecation.warn message
+      end
+
       check_class_collision
 
       def create_root_files
